@@ -1,5 +1,6 @@
-from .decorator import register, sql
+from .decorator import hydrator, register, sql
 from .executor import Executor
+from .executor.mysql import MysqlExecutor
 from .executor.postgres import PostgresExecutor
 from .hydrator import Hydrator
 from .mayim import Mayim
@@ -8,7 +9,9 @@ __all__ = (
     "Executor",
     "Hydrator",
     "Mayim",
+    "MysqlExecutor",
     "PostgresExecutor",
+    "hydrator",
     "register",
     "sql",
 )
